// 全ての検出機能のテスト(割り込み処理なし)
// スイッチを押す度に、近接 → ジェスチャー → 色・照度(ALS)と切り替える
#include <Wire.h>
#include <skAPDS9960.h>

#define SW_PIN        2       // スイッチに接続するピン番号
#define APDS9960_ADRS 0x39    // センサのI2Cアドレス
#define APDS9960_ID   0xAB    // APDS-9960のＩＤ

// 関数ライブラリの生成
skAPDS9960 APDS(APDS9960_ID,APDS9960_ADRS) ;

int SW_Flag ;

void setup()
{
     int ans ;

     pinMode(SW_PIN, INPUT) ;
     SW_Flag = 0 ;

     // シリアル通信の初期化
     Serial.begin(9600) ;

     // I2Cの初期化(マスターとする)
     Wire.begin() ;
     // ジェスチャー･センサ(APDS9960)の初期化
     ans = APDS.Init() ;
     if (ans != 0) {
          Serial.print("Init failed ans=") ;
          Serial.println(ans) ;
          while(1) ;     // 処理終了
     }
     Serial.println("Press the switch") ;
}
void loop() 
{
     int ans ;
     uint16_t  dt2[4] ;
     unsigned char dt1 ;

     /// スイッチにより各検出機能を切り替える処理 ///
     if (digitalRead(SW_PIN) == LOW) {
          Serial.println("SW ON") ;
          switch (SW_Flag) {
             case 1 :// 近接検出機能を停止する
                    ans = APDS.ProximityStop() ;
                    Serial.println("Proximity STOP") ;
                    break ;
             case 2 :// ジェスチャー検出機能を停止する
                    ans = APDS.GestureStop() ;
                    Serial.println("Gesture STOP") ;
                    break ;
             case 3 :// 色・照度(ALS)検出機能を停止する
                    ans = APDS.ColorStop() ;
                    Serial.println("ALS/Color STOP") ;
                    break ;
             default:break ;
          }
          delay(2000) ; // チャタリング防止用のウエイト
          SW_Flag++ ;
          if (SW_Flag > 3) SW_Flag = 0 ;
          switch (SW_Flag) {
             case 1 :// 近接検出機能を開始する
                    ans = APDS.ProximityStart(0,0,0) ;
                    Serial.print("Proximity START ans=") ;
                    Serial.println(ans) ;
                    break ;
             case 2 :// ジェスチャー検出機能を開始する
                    ans = APDS.GestureStart(0) ;
                    Serial.print("Gesture START ans=") ;
                    Serial.println(ans) ;
                    break ;
             case 3 :// 色・照度(ALS)検出機能を開始する
                    ans = APDS.ColorStart(0,0,0) ;
                    Serial.print("ALS/Color START ans=") ;
                    Serial.println(ans) ;
                    break ;
             default:// 内部発振器の停止(低電力スリープモード)
                    ans = APDS.PowerOnOff(PON_OFF) ;
                    Serial.print("Power OFF (Sleep mode) ans=") ;
                    Serial.println(ans) ;
                    break ;
          }
     }
     /// 各機能の表示を行う処理 ///
     switch (SW_Flag) {
        case 1 :// 近接検出機能を表示する
               APDS.ProximityRead(&dt1) ;
               Serial.print("PDATA=") ;
               Serial.println(dt1) ;
               delay(300) ;
               break ;
        case 2 :// ジェスチャー検出機能を表示する
               APDS.GestureRead(&dt1) ;
               switch (dt1) {
                    case 'U':Serial.println("UP") ;
                             break ;
                    case 'D':Serial.println("DOWN") ;
                             break ;
                    case 'L':Serial.println("LEFT") ;
                             break ;
                    case 'R':Serial.println("RIGHT") ;
                             break ;
                    default :break ;
               }
               break ;
        case 3 :// 色・照度(ALS)検出機能を表示する
               APDS.ColorRead(&dt2[0]) ;
               Serial.print("C=") ;
               Serial.print(dt2[0]) ;   // clear channel data
               Serial.print(" R=") ;
               Serial.print(dt2[1]) ;   // red channel data
               Serial.print(" G=") ;
               Serial.print(dt2[2]) ;   // green channel data
               Serial.print(" B=") ;
               Serial.println(dt2[3]) ; // blue channel data
               delay(300) ;
               break ;
        default:break ;
     }
}

