// 近接検出機能のテスト(割り込み処理で行う)
#include <Wire.h>
#include <skAPDS9960.h>

#define LED_PIN       13      // LED接続のピン番号
#define INT_PIN       2       // 割込みに接続するピン番号
#define APDS9960_ADRS 0x39    // センサのI2Cアドレス
#define APDS9960_ID   0xAB    // APDS-9960のＩＤ

skAPDS9960 APDS(APDS9960_ID,APDS9960_ADRS) ;

volatile int InterFlag ;

void InterAPDS()
{
     InterFlag = 1 ;
}
void setup()
{
     int ans ;
     
     // シリアル通信の初期化
     Serial.begin(9600) ;

     pinMode(LED_PIN, OUTPUT) ;
     pinMode(INT_PIN, INPUT) ;
     // 立下りで割り込みとする
     attachInterrupt(0, InterAPDS, FALLING) ;
     InterFlag = 0 ;

     // I2Cの初期化(マスターとする)
     Wire.begin() ;
     // ジェスチャー･センサ(APDS9960)の初期化
     ans = APDS.Init() ;
     if (ans != 0) {
          Serial.print("Init failed ans=") ;
          Serial.println(ans) ;
          while(1) ;     // 処理終了
     }
     // 近接検出機能を割り込みで開始する
     // 値が100以上(センサに近づくと数値は大きくなる)なら割り込みする
     ans = APDS.ProximityStart(1,100,0) ;
     Serial.println(ans) ;
     Serial.println("Proximity START") ;
     // 割り込み時は初期化終了までもう少し待つ
     delay(500) ;
}
void loop() 
{
     unsigned char dt ;
     
     if (InterFlag == 1) {
          // 近接検出データを読み込む
          APDS.ProximityRead(&dt) ;
          Serial.print("PDATA=") ;
          Serial.println(dt) ;
          digitalWrite(LED_PIN, HIGH) ;
          InterFlag = 0 ;
     } else digitalWrite(LED_PIN, LOW) ;

}

